colour.models.dataset.c_log Module — Colour 0.3.0 documentation

# colour.models.dataset.c_log Module

## Canon C-Log Colourspace

Defines the C-Log colourspace:

- `C_LOG_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://downloads.canon.com/CDLC/Canon-Log_Transfer_Characteristic_6-20-2012.pdf (Last accessed 18 April 2014)

`colour.models.dataset.c_log.` `C_LOG_PRIMARIES` = array([[ 0.64, 0.33], [ 0.3 , 0.6 ], [ 0.15, 0.06]])

  C-Log colourspace primaries,

  C_LOG_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.c_log.` `C_LOG_WHITEPOINT` = (0.31271, 0.32902)

  C-Log colourspace whitepoint.

  C_LOG_WHITEPOINT : tuple

`colour.models.dataset.c_log.` `C_LOG_TO_XYZ_MATRIX` = array([[ 0.41238656, 0.35759149, 0.18045049], [ 0.21263682, 0.71518298, 0.0721802 ], [ 0.01933062, 0.11919716, 0.95037259]])

  C-Log colourspace to CIE XYZ colourspace matrix.

  C_LOG_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.c_log.` `XYZ_TO_C_LOG_MATRIX` = array([[ 3.24100323, -1.53739897, -0.49861588], [-0.96922425, 1.87592998, 0.04155423], [ 0.05563942, -0.20401121, 1.05714898]])

  CIE XYZ colourspace to C-Log colourspace matrix.

  XYZ_TO_C_LOG_MATRIX : array_like, (3, 3)

`colour.models.dataset.c_log.` `C_LOG_TRANSFER_FUNCTION`(x)

  Transfer function from linear to C-Log colourspace.

  C_LOG_TRANSFER_FUNCTION : object

`colour.models.dataset.c_log.` `C_LOG_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from C-Log colourspace to linear.

  C_LOG_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.c_log.` `C_LOG_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1d410>

  C-Log colourspace.

  C_LOG_COLOURSPACE : RGB_Colourspace